/*                                                                            *
 * Author:  Jochen Rurlnder <j.rurlaender@gmx.de>                            *
 * Datum:   18.04.2004                                                        *
 * Version: 1.0                                                               *
 *                                                                            *
 * Dateiname: uart.c                                                          *
 * Beschreibung:                                                              *
 *  Diese Datei enthlt Funktionen zu Steuerung der seriellen Schnittstelle   *
 *                                                                            *
 * Versionsinfo:                                                              *
 *  - 1.0 Erste Version                                                       *
 */
#include <avr/io.h>



/*                                                                            *
 * Name: USART_INIT                                                           *
 * Beschreibung:                                                              *
 *  Initialisieren der seriellen Verbindung                                   *
 *                                                                            *
 * Infos zu Parametern:                                                       *
 * - baud: Die bertragungsgeschwindigkeit in Bit pro Sekunde                 *
 */ 
void USART_INIT( unsigned int baud)
{
	UBRRH = (unsigned int) (baud >> 8);
	UBRRL = (unsigned int) baud;
	UCSRB = (1<<RXEN) | (1<<TXEN) | (1<<RXCIE);
	UCSRC = (1<<URSEL) | (1<<USBS) | (3<<UCSZ0);
}

/*                                                                            *
 * Name: USART_Transmit                                                       *
 * Beschreibung:                                                              *
 *  Es wird ein Zeichen an die serielle Schnittstelle gesendet                *
 *                                                                            *
 * Infos zu Parametern:                                                       *
 * - data: Das in data enthaltene Zeichen wird an das USART  gesendet         *
 */
void USART_Transmit(unsigned char data)
{
	while ( !(UCSRA & (1<<UDRE)))
	;
	UDR = data;
}

/*                                                                            *
 * Name: USART_Clear_Screen                                                   *
 * Beschreibung:                                                              *
 *  Es wir eine Escaspe-Sequenz zum lschen des Bildschierminhalts in einem   *
 *  Terminalprogramm gesendet. ESC[2J [1B 5B 32 4A]                           *
 *                                                                            *
 * Infos zu Parametern:                                                       *
 * - keine                                                                    *
 */
void USART_Clear_Screen(void)
{
	USART_Transmit(0x1B);
	USART_Transmit(0x5B);
	USART_Transmit(0x32);
	USART_Transmit(0x4A);
}

/*                                                                            *
 * Name: USART_New_Line                                                       *
 * Beschreibung:                                                              *
 *  Es wir CR und LF an des Terminal gesendet -> neue Zeile                   *
 *                                                                            *
 * Infos zu Parametern:                                                       *
 * - keine                                                                    *
 */
void USART_New_Line(void)
{
  	USART_Transmit(0x0A);
	USART_Transmit(0x0D); 
}

/*                                                                            *
 * Name: USART_Transmit_String                                                *
 * Beschreibung:                                                              *
 *  Es wir ein String an die serielle Schnittstelle gesendet                  *
 *                                                                            *
 * Infos zu Parametern:                                                       *
 * - string: Der String der bermittelt werden soll                           *
 */	
void USART_Transmit_String(char* string)
{
   	while(*string)
  	{
  		USART_Transmit(*string++);
  	}
}

/*                                                                            *
 * Name: USART_Receive                                                        *
 * Beschreibung:                                                              *
 *  Es wir ein Zeichen von der seriellen Schnittstelle empfangen und an das   *
 *  aufrufende Programm zurck gesendet.                                      *
 *                                                                            *
 * Infos zu Parametern:                                                       *
 * - keine                                                                    *
 */
unsigned char USART_Receive(void)
{
    // So lange warten bis Daten empfagen wurden
    while( !(UCSRA & (1<<RXC)) )
    ;

    return UDR;    
}



